{% extends "base.html" %}
{% load kegweblib %}

{% block title %}claim_token{% endblock %}

{% block content %}
<div class="contenthead">
   claim token
</div>
<div class="content">
<p>
<form method="POST" action="">{% csrf_token %}
<table>
{{ form.as_table }}
</table>
<input type="submit">
</form>

</p>
</div>

{% endblock %}
