{% extends "account/base.html" %}
{% load kegweblib %}
{% load crispy_forms_tags %}

{% block pagetitle %}Account: Change Password{% endblock %}

{% block kb-account-main %}
<h2>Password Changed</h2>
<div class="well">
  <p>Your password has been changed.</p>
</div>

{% endblock %}
