{% load kegweblib %}

{% navitem kegadmin-main "General" exact %}
{% navitem kegadmin-taps "Taps" %}
{% navitem kegadmin-connections "Connections" %}
{% navitem kegadmin-backup-restore "Backup" %}
<li class="divider"></li>
<li><a href='{% url admin:index %}' target="_blank">Database Admin &raquo;</a></li>
<li class="divider"></li>
<li><a href='https://github.com/Kegbot/kegbot/issues' target="_blank">Report a Bug &raquo;</a></li>

